package com.zipcoder.console;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.PrintStream;

public class ConsoleTest {
    private PrintStream printStream;
    private ByteArrayOutputStream outputStream;

    @Before
    public void setup() {
        outputStream = new ByteArrayOutputStream();
        printStream = new PrintStream(outputStream);

    }

    @Test
    public void testPrint(){
        //Given
        String expectedString = "Hello";
        Console console = new Console(printStream, null);

        //When
        console.print(expectedString);

        //Then
        String actualString = outputStream.toString();
        Assert.assertEquals(expectedString, actualString);
    }

    @Test
    public void testNextLine() {
        String expectedString = "stay";
        InputStream inputStream = new ByteArrayInputStream(expectedString.getBytes());
        Console console = new Console(null, inputStream);

        //When
        String actualString = console.nextLine();

        //Then
        Assert.assertEquals(expectedString, actualString);
    }

    @Test
    public void testPrintAndRead(){
        String question = "Hit or stay?";

        String answer = "stay";
        InputStream inputStream = new ByteArrayInputStream(answer.getBytes());
        Console console = new Console(printStream, inputStream);

        //When
        String userInput = console.ask();

        //Then
        Assert.assertEquals(question, outputStream.toString());
        Assert.assertEquals(answer, userInput);
    }
}
